<?php
/**
 * Tooltip Plugin: Create tooltips for sections of wikitext.
 *
 *   syntax: {!tooltipee:tooltiped}}
 *
 * @file       tooltip/syntax/short.php
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Luis Machuca B. <luis.machuca@gulix.cl>
 * @brief      CSS-based one-word toltips
 * @version    1.5
 *
 *   This plugin allows to insert "tooltips" in DokuWiki text, so that 
 *  hovering the mouse over the mrked text will reveal the tooltip.
 *  The wikitext that composes the tooltip is parsed for basic 
 *  formatting only (underlines, italics and bolds). Otherwise,
 *  the plugin is perfectly usable.
 *   This plugin uses CSS only; no JavaScript or server side help
 *  (beyond the actual tag parsing) is used to harm any animal, 
 *  in any way.
 *
 *   For a live demo check instructions in the lugin page.
 *
 *  Greetings.
 *        - Luis Machuca B. <a.k.a. 'ryan.chappelle'>
 */

if(!defined('DW_LF')) define('DW_LF',"\n");
 
if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');
 
 
class syntax_plugin_tooltip_short extends DokuWiki_Syntax_Plugin
{
  function getInfo()
  {
    return array(
           'author' => 'Luis Machuca B.',
           'email'  => 'luis.machuca@gmail.com',
           'date'   => '2009-03-04',
           'name'   => 'Tooltip Plugin',
           'desc'   => 'Provides one-word tooltips: {!word:description}}.',
           'url'    => 'http://www.dokuwiki.org/plugin:tooltip',
           );
  }

  function getType()    { 
    return 'formatting'; 
  }

  function getAllowedTypes()  {
    return array('substition','disabled','formatting');
  }

  function getPType()  { 
    return 'normal'; 
  }

  function getSort() { 
    return 400; 
  } // get by exp
 
  function connectTo($mode)  {
    $this->Lexer->addEntryPattern(
                  '\{\!\w+:(?=.*?\}\})',
                  $mode, 
                  'plugin_tooltip_short' );
  }

  function postConnect() {
    $this->Lexer->addExitPattern(
                  '\}\}',
                  'plugin_tooltip_short');
  }

  function handle($match, $state, $pos, &$handler) {
    // remove the delimiters
    $data= array();
    $data['state']= $state;
    switch ($state)  {
      case DOKU_LEXER_ENTER: {
         $match= substr($match, 2, -1);
        $data['mark']= $match;
        break;
      }
      case DOKU_LEXER_UNMATCHED: {
        $data['content']= $match;
        break;
      }
    } // end switch ($state)
    return $data;
  } // end function

  function render($mode, &$renderer, $data) {
    static $counter= 0;
    $state= $data['state'];
    $style= "tooltip_inline";
    $mark= $data['mark'];
    $content= $data['content'];

    if($mode == 'xhtml') {
      /* let's do the jon thingie, that is, 
         create the HTML code that reveals the tooltip
       */
      switch ($state) {
        case DOKU_LEXER_ENTER: {
          $renderer->doc.= '<span class="'. $style. '"><span>'. DW_LF;
          $renderer->doc.= $renderer->_xmlEntities($mark);
          $renderer->doc.= '<span class="tip">';
          break;
        }
        case DOKU_LEXER_UNMATCHED: {
          $renderer->doc.= $renderer->_xmlEntities($content);
          //$renderer->doc.= $this->_get_rendering($content, $renderer);
          break;
        }
        case DOKU_LEXER_EXIT: {
          $renderer->doc.= '</span> </span>';
          $renderer->doc.= '</span>';
          break;
        }
      } // end switch
      return true;
    } // end if (xhtml)
    // no more renderers
    return false;
  }

  /**
   * From this point on, local functions
   */
  function _get_rendering($content, &$renderer) {
    $wt  = p_get_instructions($content);
    $xt  = p_render('xhtml', $wt, $info);
    $xt  = str_replace('\n', '', $xt);
    //$xt  = str_replace('\n\r', '', $xt);
    $xt  = str_replace('<p>', '', $xt);
    $xt  = str_replace('</p>', '', $xt);
    return trim($xt);
  }

}
